pub struct VirtioHal;Trait Implementations
Sourceimpl Hal for VirtioHal
impl Hal for VirtioHal
Sourcefn dma_alloc(pages: usize) -> usize
fn dma_alloc(pages: usize) -> usize
Allocates the given number of contiguous physical pages of DMA memory for virtio use.
Sourcefn dma_dealloc(pa: usize, pages: usize) -> i32
fn dma_dealloc(pa: usize, pages: usize) -> i32
Deallocates the given contiguous physical DMA memory pages.
Sourcefn phys_to_virt(addr: usize) -> usize
fn phys_to_virt(addr: usize) -> usize
Converts a physical address used for virtio to a virtual address which the program can
access.
Sourcefn virt_to_phys(vaddr: usize) -> usize
fn virt_to_phys(vaddr: usize) -> usize
Converts a virtual address which the program can access to the corresponding physical
address to use for virtio.